@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -15,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-lambda-layer-curl",
-    "2.0.698",
+    "2.0.705",
     __name__[0:-6],
-    "cdk-lambda-layer-curl@2.0.698.jsii.tgz",
+    "cdk-lambda-layer-curl@2.0.705.jsii.tgz",
 )
 
 __all__ = [
